from .base import Component
from typing import List, Dict, Union



class Template(Component):
    def __init__(self, component: Component) -> None:
        super().__init__(component)

    def __str__(self) -> str:
        return self.children



from bs4 import BeautifulSoup
from typing import List, Union
from .base import Component


def format_html(components: Union[Component, List[Component]]) -> str:
    # Convert the component to a string
    if isinstance(components, list):
        html_str = ''.join([str(component) for component in components])
    else:
        html_str = str(components)

    # Parse the HTML string with BeautifulSoup
    soup = BeautifulSoup(html_str, 'html.parser')

    # Use the prettify() method to add indentation
    formatted_html = soup.prettify()

    return formatted_html



from setuptools import setup, find_packages
import pathlib
import shutil

# removing dist/ and whitehouse.egg-info/ directories
shutil.rmtree("dist", ignore_errors=True)
shutil.rmtree("whitehouse.egg-info", ignore_errors=True)

setup(
    name="whitehouse",
    version="0.3.0",
    description="An html templating library for Python",
    author="Minh-Quan Do",
    author_email="mdo9@gmu.edu",
    long_description=pathlib.Path("README.md").read_text(),
    long_description_content_type='text/markdown',
    packages=find_packages(exclude=["__pycache__", "*.pyc", "*.pyo"]),
    exclude_package_data={
        '': ['__pycache__', '*.pyc', '*.pyo']
    },
    install_requires=[
        'beautifulsoup4'
    ]
)